#ifndef DAILYMOTIONACCOUNTSLISTMODEL_H
#define DAILYMOTIONACCOUNTSLISTMODEL_H

#include <QSqlTableModel>

class DailymotionAccountsListModel : public QSqlTableModel
{
    Q_OBJECT

    Q_PROPERTY(int count
               READ rowCount
               NOTIFY countChanged)

public:
    enum Roles {
        DisplayNameRole = Qt::DisplayRole,
        UsernameRole,
        AccessTokenRole,
        RefreshTokenRole,
        ActiveRole
    };

public:
    explicit DailymotionAccountsListModel(QObject *parent = 0);
    ~DailymotionAccountsListModel();
    QVariant data(const QModelIndex &idx, int role) const;
    Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;

public slots:
    void switchAccount(int row);
    void addAccount(const QString &displayName, const QString &token, const QString &refresh);
    void deleteAccount(int row);

private:
    void setActiveAccount(int row);

signals:
    void accountSelected(const QString &user, const QString &token, const QString &refresh);
    void accountAdded(const QString &user, const QString &token, const QString &refresh);
    void accountDeleted();
    void error(const QString &errorString);
    void countChanged(int count);
};

#endif // DAILYMOTIONACCOUNTSLISTMODEL_H
